<?php

/*  THEME OPTIONS PANEL
-----------------------------------------------------------------------------------*/

/* Set the file path based on whether the Options Framework is in a parent theme or child theme */

if ( get_stylesheet_directory() == get_template_directory() ) {
	define('OF_FILEPATH', get_template_directory());
	define('OF_DIRECTORY', get_template_directory_uri());
} else {
	define('OF_FILEPATH', get_stylesheet_directory());
	define('OF_DIRECTORY', get_stylesheet_directory_uri());
}

/* These files build out the options interface.  Likely won't need to edit these. */

require_once (OF_FILEPATH . '/admin/admin-functions.php');		// Custom functions and plugins
require_once (OF_FILEPATH . '/admin/admin-interface.php');		// Admin Interfaces (options,framework, seo)

/* These files build out the theme specific options and associated functions. */

require_once (OF_FILEPATH . '/admin/theme-options.php'); 		// Options panel settings and custom settings
require_once (OF_FILEPATH . '/admin/theme-functions.php');	// Theme actions based on options settings




/*  Functions
-----------------------------------------------------------------------------------*/

include(get_template_directory() . '/functions/shortcodes.php');
include(get_template_directory() . '/functions/paging.php');
include(get_template_directory() . '/functions/comments-template.php');

/* ------------------------------------------------------------------------------------------------------------------------------------------------------ */

	function my_enqueue_scripts()
	{
		
		// Register our stylesheets

		wp_register_style( 'bootstrapresponsive', get_template_directory_uri() . '/resources/css/bootstrap-responsive.css' );
		wp_register_style( 'bootstrap', get_template_directory_uri() . '/resources/css/bootstrap.css' );
		wp_register_style( 'main', get_template_directory_uri() . '/resources/css/screen.css' );
		wp_register_style( 'typography', get_template_directory_uri() . '/resources/css/typography.css' );
		wp_register_style( 'googleprettify', get_template_directory_uri() . '/resources/js/google-code-prettify/prettify.css' );
		wp_register_style( 'jplayer-style', get_template_directory_uri() . '/resources/jplayer/jplayer.css', 'default-style', '1.0');
		wp_register_style( 'flexslidercss', get_template_directory_uri() . '/resources/css/flexslider.css' );
		
		// Register our scripts
		wp_deregister_script( 'jquery' );
		
		wp_register_script( 'jquery', get_template_directory_uri() . '/resources/js/jquery-1.7.1.min.js', 'jquery' );
		
		wp_register_script( 'twitter', get_template_directory_uri() . '/widgets/js/jquery.tweet.js', 'jquery' );
		wp_register_script( 'easing', get_template_directory_uri() . '/resources/js/jquery.easing.1.3.js', 'jquery' );
		wp_register_script( 'superfish', get_template_directory_uri() . '/resources/js/superfish.js', 'jquery' );
		wp_register_script( 'jplayer', get_template_directory_uri() . '/resources/jplayer/jquery.jplayer.min.js', 'jquery' );
		wp_register_script( 'isotope', get_template_directory_uri() . '/resources/js/jquery.isotope.min.js', 'jquery' );
		wp_register_script( 'prettify', get_template_directory_uri() . '/resources/js/google-code-prettify/prettify.js', 'jquery' );
		wp_register_script( 'flexslider', get_template_directory_uri() . '/resources/js/jquery.flexslider-min.js', 'jquery' );
		wp_register_script( 'bootstrapmin', get_template_directory_uri() . '/resources/js/bootstrap.min.js', 'jquery' );
		wp_register_script( 'mainapp', get_template_directory_uri() . '/resources/js/application.js', 'jquery' );
		
		// Enqueue our scripts
		wp_enqueue_script( 'jquery' );
		wp_enqueue_script( 'twitter' );
		wp_enqueue_script( 'easing' );
		wp_enqueue_script( 'superfish' );
		wp_enqueue_script( 'prettify' );
		wp_enqueue_script( 'bootstrapmin' );
		wp_enqueue_script( 'mainapp' );
		
		// Enqueue our styles

		wp_enqueue_style( 'bootstrap' );
		wp_enqueue_style( 'bootstrapresponsive' );
		wp_enqueue_style( 'main' );
		wp_enqueue_style( 'typography' );
		wp_enqueue_style( 'googleprettify' );
		
		// load scripts on appropriate pages
		if( is_page_template( 'portfolio.php' ) ) {
			wp_enqueue_script( 'isotope');
    	}
    	if( is_page_template( 'single-portfolio.php' ) ||  is_page_template( 'homepage.php' ) || is_page_template( 'full_width_page.php' ) || is_single() || is_home() || is_category()  || is_tag() || is_search() || is_archive() ) {
    	    wp_enqueue_script( 'flexslider' ); 
			wp_enqueue_style( 'flexslidercss' );
			wp_enqueue_script( 'jplayer' ); 
			wp_enqueue_style( 'jplayer-style' );
    	}
	}
	
	add_action( 'wp_enqueue_scripts', 'my_enqueue_scripts' );
	


/*  Slider Functions
-----------------------------------------------------------------------------------*/

include('includes/revslider/revslider.php');

// Adding post/work meta boxes
include("functions/theme-postmeta.php");

/*  Post types
-----------------------------------------------------------------------------------*/
function create_post_type_portfolio()
	{
		$labels = array('name' => __( 'Portfolio Items', 'themeText' ),
						'singular_name' => __( 'Portfolio Item', 'themeText' ),
						'add_new' => __( 'Add New Item', 'themeText' ),
						'add_new_item' => __( 'Add New Portfolio Item', 'themeText' ),
						'edit_item' => __( 'Edit Portfolio Item', 'themeText' ),
						'new_item' => __( 'New Portfolio Item', 'themeText' ),
						'view_item' => __( 'View Portfolio Item', 'themeText' ),
						'search_items' => __( 'Search Portfolio Items', 'themeText' ),
						'not_found' =>  __( 'No Portfolio Items found', 'themeText' ),
						'not_found_in_trash' => __( 'No Portfolio Items found in Trash', 'themeText' ),
						'parent_item_colon' => '',
						'menu_name' => 'Portfolio');
		
		$args = array(  'labels' => $labels,
						'public' => true,
						'publicly_queryable' => true,
						'show_ui' => true,
						'query_var' => true,
						'show_in_nav_menus' => true,
						'menu_icon' => get_template_directory_uri() . '/resources/img/cleminmenuportfolio.png',
						'capability_type' => 'post',
						'hierarchical' => false,
						'menu_position' => 5,
						'supports' => array( 'title', 'editor', 'thumbnail', 'revisions', ),
						'rewrite' => array( 'slug' => 'portfolio', 'with_front' => false ));
		
		register_post_type( 'portfolio' , $args );
	}
	
	add_action( 'init', 'create_post_type_portfolio' );

	function portfolio_updated_messages( $messages )
	{
		global $post, $post_ID;
		
		$messages['portfolio'] = array( 0 => '', // Unused. Messages start at index 1.
										1 => sprintf( __( 'Portfolio Item updated. <a href="%s">View Portfolio Item</a>', 'themeText' ), esc_url( get_permalink( $post_ID) ) ),
										2 => __( 'Custom field updated.', 'themeText' ),
										3 => __( 'Custom field deleted.', 'themeText' ),
										4 => __( 'Portfolio Item updated.', 'themeText' ),
										// translators: %s: date and time of the revision
										5 => isset( $_GET['revision'] ) ? sprintf( __( 'Portfolio Item restored to revision from %s', 'themeText' ), wp_post_revision_title( ( int ) $_GET['revision'], false ) ) : false,
										6 => sprintf( __( 'Portfolio Item published. <a href="%s">View Portfolio Item</a>', 'themeText' ), esc_url( get_permalink( $post_ID) ) ),
										7 => __( 'Portfolio Item saved.', 'themeText' ),
										8 => sprintf( __( 'Portfolio Item submitted. <a target="_blank" href="%s">Preview Portfolio Item</a>', 'themeText' ), esc_url( add_query_arg( 'preview', 'true', get_permalink($post_ID) ) ) ),
										9 => sprintf( __( 'Portfolio Item scheduled for: <strong>%1$s</strong>. <a target="_blank" href="%2$s">Preview Portfolio Item</a>', 'themeText' ),
										// translators: Publish box date format, see http://php.net/date
										date_i18n( __( 'M j, Y @ G:i', 'themeText' ), strtotime( $post->post_date ) ), esc_url( get_permalink( $post_ID) ) ),
										10 => sprintf( __( 'Portfolio Item draft updated. <a target="_blank" href="%s">Preview Portfolio Item</a>', 'themeText' ), esc_url( add_query_arg( 'preview', 'true', get_permalink( $post_ID) ) ) ) );
	
		return $messages;
	}

	
	add_filter( 'post_updated_messages', 'portfolio_updated_messages' );

	function portfolio_taxonomy()
	{
		$labels = array('name' => __( 'Departments', 'themeText' ),
						'singular_name' => __( 'Department', 'themeText' ),
						'search_items' =>  __( 'Search Departments', 'themeText' ),
						'all_items' => __( 'All Departments', 'themeText' ),
						'parent_item' => __( 'Parent Department', 'themeText' ),
						'parent_item_colon' => __( 'Parent Department:', 'themeText' ),
						'edit_item' => __( 'Edit Department', 'themeText' ),
						'update_item' => __( 'Update Department', 'themeText' ),
						'add_new_item' => __( 'Add New Department', 'themeText' ),
						'new_item_name' => __( 'New Department Name', 'themeText' ),
						'menu_name' => __( 'Departments', 'themeText' ) );

		register_taxonomy(  'department',
							array( 'portfolio' ),
							array( 'hierarchical' => true,
							'labels' => $labels,
							'show_ui' => true,
							'public' => true,
							'query_var' => true,
							'rewrite' => array( 'slug' => 'department' )));
	}
	
	add_action( 'init', 'portfolio_taxonomy' );


	function portfolio_edit_columns( $pf_columns )
	{
		$pf_columns = array('cb' => '<input type="checkbox" />',
							'title' => __( 'Portfolio Title', 'themeText' ),
							'screenshot' => __( 'Screen Shot', 'themeText' ),
							'department' => __( 'Department', 'themeText' ),
							'portfolio_type_column' => __( 'Portfolio Item Type', 'themeText' ),
							'short_description' => __( 'Short Description', 'themeText' ) );
		
		return $pf_columns;
	}
	
	add_filter( 'manage_edit-portfolio_columns', 'portfolio_edit_columns' );

	function portfolio_custom_columns( $pf_column )
	{
		global $post, $post_ID;
		
		switch ( $pf_column )
		{
			case 'screenshot':
				if ( has_post_thumbnail() )
				{
					the_post_thumbnail( 'slide_small_img' );
				}
				break;
			
			case 'department':
				$taxon = 'department';
				$terms_list = get_the_terms( $post_ID, $taxon );
				if ( !empty( $terms_list ) )
				{
					$out = array();
					foreach ( $terms_list as $term_list )
						$out[] = '<a href="edit.php?post_type=portfolio&department=' .$term_list->slug .'">' .$term_list->name .' </a>';
					echo join( ', ', $out );
				}
				break;
				
			case 'portfolio_type_column':
				$portfoio_type2_column = get_post_meta( $post->ID, 'portfoio_format_type2', true );
				$portfoio_type3_column = get_post_meta( $post->ID, 'portfoio_format_type3', true );
				if ($portfoio_type2_column)
				{
					echo 'Gallery';
				}
				elseif ($portfoio_type3_column)
				{
					echo 'Video';
				}
				else
				{
					echo 'Standart';
				}
				break;
			
			case 'short_description':
				echo get_post_meta( $post->ID, 'short_description', true );
				break;
		}
	}
	
	add_action( 'manage_posts_custom_column',  'portfolio_custom_columns' );
	
	function portfolio_details()
	{
		global $post, $post_ID;
	
		$portfoio_format_type2 = get_post_meta( $post->ID, 'portfoio_format_type2', true );
		$portfoio_format_type3 = get_post_meta( $post->ID, 'portfoio_format_type3', true );
		$short_description = get_post_meta( $post->ID, 'short_description', true );
		
		$project = get_post_meta( $post->ID, 'project', true );
		$client = get_post_meta( $post->ID, 'client', true );
		$long_description = get_post_meta( $post->ID, 'long_description', true );
		$technology = get_post_meta( $post->ID, 'technology', true );
		$launch_project_url = get_post_meta( $post->ID, 'launch_project_url', true );
		$project_url_new_window = get_post_meta( $post->ID, 'project_url_new_window', true );
		
		$portfolio_video_code = get_post_meta( $post->ID, 'portfolio_video_code', true );
?>
		<div class="admin-inside-box">
			<p>
				<input type="hidden" name="portfolio_nonce" value="<?php echo wp_create_nonce( basename(__FILE__) ); ?>" />
			</p>
			
			<p style="border-bottom: 1px solid #dfdfdf; padding-bottom: 20px; margin-bottom: 0px;">
			
				<label style="display: block; cursor: default; margin-bottom: 5px; width: 100%;"><?php echo __( 'Portfolio Item Type', 'themeText' ); ?></label>
				
				<label style="display: inline-block; margin-bottom: 3px;"><input type="radio" id="portfoio_format_type1" name="portfoio_format_type1" value="portfoio_format_standart" <?php if ( (!$portfoio_format_type2) && (!$portfoio_format_type3) ) { echo 'checked="checked"'; } ?> /> <?php echo __( 'Standart', 'themeText' ); ?></label>
				<br>
				<label style="display: inline-block; margin-bottom: 3px;"><input type="radio" id="portfoio_format_type2" name="portfoio_format_type2" value="portfoio_format_gallery" <?php if ($portfoio_format_type2) { echo 'checked="checked"'; } ?> /> <?php echo __( 'Gallery', 'themeText' ); ?></label>
				<br>
				<label style="display: inline-block;"><input type="radio" id="portfoio_format_type3" name="portfoio_format_type3" value="portfoio_format_video" <?php if ($portfoio_format_type3) { echo 'checked="checked"'; } ?> /> <?php echo __( 'Video', 'themeText' ); ?></label>
				<script src="https://ajax.googleapis.com/ajax/libs/jquery/1.7.1/jquery.min.js"></script>
				<script>
					$(function()
					{
						$("#portfolio_type_box").hide();
					
						$('#portfoio_format_type1').click(function()
						{
							$("#portfoio_format_type2").removeAttr("checked");
							$("#portfoio_format_type3").removeAttr("checked");
							$("#portfoio_format_type1").attr("checked", "checked");
							$("#portfolio_type_box").hide();
						});
						
						$('#portfoio_format_type2').click(function()
						{
							$("#portfoio_format_type1").removeAttr("checked");
							$("#portfoio_format_type3").removeAttr("checked");
							$("#portfoio_format_type2").attr("checked", "checked");
							$("#portfolio_type_box").show();
							$(".portfolio-type-gallery").show();
							$(".portfolio-type-video").hide();
						});
						
						$('#portfoio_format_type3').click(function()
						{
							$("#portfoio_format_type1").removeAttr("checked");
							$("#portfoio_format_type2").removeAttr("checked");
							$("#portfoio_format_type3").attr("checked", "checked");
							$("#portfolio_type_box").show();
							$(".portfolio-type-video").show();
							$(".portfolio-type-gallery").hide();
						});
						
						if ( $("#portfoio_format_type2").attr("checked") == "checked" )
						{
							$("#portfolio_type_box").show();
							$(".portfolio-type-gallery").show();
							$(".portfolio-type-video").hide();
						}
						
						if ( $("#portfoio_format_type3").attr("checked") == "checked" )
						{
							$("#portfolio_type_box").show();
							$(".portfolio-type-video").show();
							$(".portfolio-type-gallery").hide();
						}

					});
				</script>
		
			</p>
			
			<p style="border-top: 1px solid #ffffff; border-bottom: 1px solid #dfdfdf; padding-top: 20px; padding-bottom: 20px; margin-top: 0px; margin-bottom: 0px;">
				<label for="short_description"><?php echo __( 'Short Description (optional)', 'themeText' ); ?></label>
				<input type="text" id="short_description" name="short_description" style="width: 100%;" value="<?php echo $short_description; ?>" />
			</p>
			
			<p style="border-top: 1px solid #ffffff; padding-top: 20px; margin-top: 0px;">
				<label for="project"><?php echo __( 'Project', 'themeText' ); ?></label>
				<input type="text" id="project" name="project" style="width: 100%;" value="<?php echo $project; ?>" />
			</p>
			
			<p>
				<label for="client"><?php echo __( 'Client', 'themeText' ); ?></label>
				<input type="text" id="client" name="client" style="width: 100%;" value="<?php echo $client; ?>" />
			</p>
			
			<p>
				<label for="long_description"><?php echo __( 'Description', 'themeText' ); ?></label>
				<input type="text" id="long_description" name="long_description" style="width: 100%;" value="<?php echo $long_description; ?>" />
			</p>
			
			<p>
				<label for="technology"><?php echo __( 'Technology', 'themeText' ); ?></label>
				<input type="text" id="technology" name="technology" style="width: 100%;" value="<?php echo $technology; ?>" />
			</p>
			
			<p>
				<label for="launch_project_url"><?php echo __( 'Launch Project URL', 'themeText' ); ?></label>
				<input type="text" id="launch_project_url" name="launch_project_url" style="width: 100%;" value="<?php echo $launch_project_url; ?>" />
				<label style="display: inline-block; font-size: 11px; color: #666666; margin-top: 5px;"><input type="checkbox" <?php if ($project_url_new_window) echo 'checked="checked"' ?> id="project_url_new_window" name="project_url_new_window" value="new_window" /> <?php echo __( 'Open link in new window', 'themeText' ); ?></label>
			</p>
		</div>
<?php
	}

	function add_portfolio_metabox()
	{
		add_meta_box( 'portfolio_meta_box', __( 'Portfolio Item Details', 'themeText' ), 'portfolio_details', 'portfolio', 'side', 'default' );
	}
	
	add_action( 'admin_init', 'add_portfolio_metabox' );
	
	function portfolio_type()
	{
		global $post, $post_ID;
		
		$upload_one = get_post_meta( $post->ID, 'upload_one', true );
		$upload_two = get_post_meta( $post->ID, 'upload_two', true );
		$upload_three = get_post_meta( $post->ID, 'upload_three', true );
		$upload_four = get_post_meta( $post->ID, 'upload_four', true );
		$upload_five = get_post_meta( $post->ID, 'upload_five', true );
		$upload_six = get_post_meta( $post->ID, 'upload_six', true );
		$upload_seven = get_post_meta( $post->ID, 'upload_seven', true );
		$upload_eight = get_post_meta( $post->ID, 'upload_eight', true );
		$upload_nine = get_post_meta( $post->ID, 'upload_nine', true );
		$upload_ten = get_post_meta( $post->ID, 'upload_ten', true );
		
		$portfolio_video_code = get_post_meta( $post->ID, 'portfolio_video_code', true );
		
	?>
		
		<div class="portfolio-type-gallery">
			<h2><?php echo __( 'Gallery', 'themeText' ); ?></h2>
			
			<script>
				$(function()
				{
					var uploadID = ''; /* setup the var */

					jQuery('.upload-button').click(function() {
						uploadID = jQuery(this).prev('input'); /* grab the specific input */
						formfield = jQuery('.upload').attr('name');
						tb_show('', 'media-upload.php?type=image&amp;TB_iframe=true');
						return false;
					});

					window.send_to_editor = function(html) {
						imgurl = jQuery('img',html).attr('src');
						uploadID.val(imgurl); /* assign the value to the input */
						tb_remove();
					}
				});
			</script>

			<p class="upload_field">
				<label for="upload_one"><?php echo __( 'Image 1', 'themeText' ); ?></label>
				<input type="text" id="upload_one" name="upload_one" class="upload" style="width: 75%;" value="<?php  echo $upload_one; ?>" />
				<input type="button" class="upload-button button" value="Upload Image" />
			</p>

			<p class="upload_field">
				<label for="upload_two"><?php echo __( 'Image 2', 'themeText' ); ?></label>
				<input type="text" id="upload_two" name="upload_two" class="upload" style="width: 75%;" value="<?php  echo $upload_two; ?>" />
				<input type="button" class="upload-button button" value="Upload Image" />
			</p>

			<p class="upload_field">
				<label for="upload_three"><?php echo __( 'Image 3', 'themeText' ); ?></label>
				<input type="text" id="upload_three" name="upload_three" class="upload" style="width: 75%;" value="<?php  echo $upload_three; ?>" />
				<input type="button" class="upload-button button" value="Upload Image" />
			</p>
			
			<p class="upload_field">
				<label for="upload_four"><?php echo __( 'Image 4', 'themeText' ); ?></label>
				<input type="text" id="upload_four" name="upload_four" class="upload" style="width: 75%;" value="<?php  echo $upload_four; ?>" />
				<input type="button" class="upload-button button" value="Upload Image" />
			</p>

			<p class="upload_field">
				<label for="upload_five"><?php echo __( 'Image 5', 'themeText' ); ?></label>
				<input type="text" id="upload_five" name="upload_five" class="upload" style="width: 75%;" value="<?php  echo $upload_five; ?>" />
				<input type="button" class="upload-button button" value="Upload Image" />
			</p>
			
			<p class="upload_field">
				<label for="upload_six"><?php echo __( 'Image 6', 'themeText' ); ?></label>
				<input type="text" id="upload_six" name="upload_six" class="upload" style="width: 75%;" value="<?php  echo $upload_six; ?>" />
				<input type="button" class="upload-button button" value="Upload Image" />
			</p>
			
			<p class="upload_field">
				<label for="upload_seven"><?php echo __( 'Image 7', 'themeText' ); ?></label>
				<input type="text" id="upload_seven" name="upload_seven" class="upload" style="width: 75%;" value="<?php  echo $upload_seven; ?>" />
				<input type="button" class="upload-button button" value="Upload Image" />
			</p>
			
			<p class="upload_field">
				<label for="upload_eight"><?php echo __( 'Image 8', 'themeText' ); ?></label>
				<input type="text" id="upload_eight" name="upload_eight" class="upload" style="width: 75%;" value="<?php  echo $upload_eight; ?>" />
				<input type="button" class="upload-button button" value="Upload Image" />
			</p>
			
			<p class="upload_field">
				<label for="upload_nine"><?php echo __( 'Image 9', 'themeText' ); ?></label>
				<input type="text" id="upload_nine" name="upload_nine" class="upload" style="width: 75%;" value="<?php  echo $upload_nine; ?>" />
				<input type="button" class="upload-button button" value="Upload Image" />
			</p>
			
			<p class="upload_field">
				<label for="upload_ten"><?php echo __( 'Image 10', 'themeText' ); ?></label>
				<input type="text" id="upload_ten" name="upload_ten" class="upload" style="width: 75%;" value="<?php  echo $upload_ten; ?>" />
				<input type="button" class="upload-button button" value="Upload Image" />
			</p>
		</div>
		
		<div class="portfolio-type-video">
			<h2><?php echo __( 'Video', 'themeText' ); ?></h2>
			<label for="portfolio_video_code"><?php echo __( 'Video Embed Code', 'themeText' ); ?></label>
			<textarea id="portfolio_video_code" name="portfolio_video_code" style="outline: none; width: 100%;" rows="4" cols="50"><?php  echo $portfolio_video_code; ?></textarea>
		</div>
	<?php
	}
	
	function add_metabox_portfolio_type()
	{		
		add_meta_box( 'portfolio_type_box', __( 'Portfolio Item Type', 'themeText' ), 'portfolio_type', 'portfolio', 'advanced', 'high' );
	}
	
	add_action( 'admin_init', 'add_metabox_portfolio_type' );

	function save_portfolio_details( $post_id )
	{
		global $post, $post_ID;
	
		if ( !wp_verify_nonce( @$_POST['portfolio_nonce'], basename(__FILE__) ) )
		{
			return $post_id;
		}

		if ( $_POST['post_type'] == 'portfolio' )
		{
			if ( !current_user_can( 'edit_page', $post_id ) )
				return $post_id;
		}
		else
		{
			if ( !current_user_can( 'edit_post', $post_id ) )
			return $post_id;
		}
	
		if ( $_POST['post_type'] == 'portfolio' )
		{
			update_post_meta( $post->ID, 'portfoio_format_type2', $_POST['portfoio_format_type2'] );
			update_post_meta( $post->ID, 'portfoio_format_type3', $_POST['portfoio_format_type3'] );
			update_post_meta( $post->ID, 'short_description', $_POST['short_description'] );
			update_post_meta( $post->ID, 'project', $_POST['project'] );
			update_post_meta( $post->ID, 'client', $_POST['client'] );
			update_post_meta( $post->ID, 'long_description', $_POST['long_description'] );
			update_post_meta( $post->ID, 'technology', $_POST['technology'] );
			update_post_meta( $post->ID, 'launch_project_url', $_POST['launch_project_url'] );
			update_post_meta( $post->ID, 'project_url_new_window', $_POST['project_url_new_window'] );
			
			update_post_meta( $post->ID, 'upload_one', $_POST['upload_one'] );
			update_post_meta( $post->ID, 'upload_two', $_POST['upload_two'] );
			update_post_meta( $post->ID, 'upload_three', $_POST['upload_three'] );
			update_post_meta( $post->ID, 'upload_four', $_POST['upload_four'] );
			update_post_meta( $post->ID, 'upload_five', $_POST['upload_five'] );
			update_post_meta( $post->ID, 'upload_six', $_POST['upload_six'] );
			update_post_meta( $post->ID, 'upload_seven', $_POST['upload_seven'] );
			update_post_meta( $post->ID, 'upload_eight', $_POST['upload_eight'] );
			update_post_meta( $post->ID, 'upload_nine', $_POST['upload_nine'] );
			update_post_meta( $post->ID, 'upload_ten', $_POST['upload_ten'] );
			
			update_post_meta( $post->ID, 'portfolio_video_code', $_POST['portfolio_video_code'] );
		}
	}
	
	add_action( 'save_post', 'save_portfolio_details' );

	function only_show_departments()
	{
		global $typenow;
		
		if ( $typenow == 'portfolio' )
		{
			$filters = array( 'department' );
			
			foreach ( $filters as $tax_slug )
			{
				$tax_obj = get_taxonomy( $tax_slug );
				$tax_name = $tax_obj->labels->name;
				$terms = get_terms( $tax_slug );
			
				echo '<select name="' .$tax_slug .'" id="' .$tax_slug .'" class="postform">';
				echo '<option value="">Show All ' .$tax_name .'</option>';
				
				foreach ( $terms as $term )
				{
					echo '<option value='. $term->slug, @$_GET[$tax_slug] == $term->slug ? ' selected="selected"' : '','>' . $term->name .' (' . $term->count .')</option>';
				}
				echo '</select>';
			}
		}
	}

	add_action( 'restrict_manage_posts', 'only_show_departments' );

	function get_nav_menu_id($template)
	{
		static $nav_menu_id;
		
		if ( !isset( $nav_menu_id ) )
		{
			global $wpdb;
			
			$sql = <<<SQL
			SELECT menu.post_id AS menu_id FROM {$wpdb->postmeta}
			AS template INNER JOIN {$wpdb->postmeta}
			AS menu_id ON menu_id.meta_key='_menu_item_object_id'
                        AND menu_id.meta_value=template.post_id
			INNER JOIN {$wpdb->postmeta} AS menu ON menu_id.post_id=menu.post_id
			WHERE 1=1
			AND menu.meta_key='_menu_item_object' AND menu.meta_value='page'
			AND template.meta_key='_wp_page_template' AND template.meta_value='%s'
SQL;
			$nav_menu_id = $wpdb->get_var( $wpdb->prepare( $sql, $template ) );
		}
		
		return $nav_menu_id;
	}

	function remove_class($var)
	{
		if ( $var == 'current_page_parent' )
		{
			return false;
		}
		
		return true;
	}

	function add_class_to_menu($current)
	{
		global $wp_query, $post;
		
		$post_type = get_query_var( 'post_type' );
		$term_type = get_query_var( 'taxonomy' );
		
		if ( $post_type == 'portfolio' || $term_type == 'department' || is_404() )
		{
			$current = array_filter( $current, 'remove_class' );

			if ( !is_404() )
			{
				// get nav_menu_id from products page that using page template (products_page.php)
				$menu_id = 'menu-item-' . get_nav_menu_id( 'portfolio.php' );
				
				if ( in_array( $menu_id, $current) )
				{
					$current[] = 'current_page_parent';
				}
			}
		}
		
		return $current;
	}
	
	// check if we are not in backend
	if ( !is_admin() )
	{
		add_filter( 'nav_menu_css_class', 'add_class_to_menu' );
	}
	


/*  Widgets
-----------------------------------------------------------------------------------*/
include(get_template_directory() . '/widgets/widgets.php');


/*-----------------------------------------------------------------------------------
	Misc Stuff
-----------------------------------------------------------------------------------*/
add_theme_support( 'automatic-feed-links' );

/*  Add Featured image
-----------------------------------------------------------------------------------*/
add_theme_support( 'post-thumbnails', array( 'post', 'slides', 'portfolio' ) );
add_image_size( 'home_latest_post_img', 740, 9999, true );
add_image_size( 'home_latest_portfolio_img', 312, 250, true );
add_image_size( 'blog-single', 770, 600, true );
add_image_size( 'blog-list', 770, 300, true );
add_image_size( 'featured_post', 70, 52, true );


if ( ! isset( $content_width ) ) $content_width = 1170;

/*  Wordpress menu feature 
-----------------------------------------------------------------------------------*/
register_nav_menus( array(
	'main' => __( 'Main Menu', 'themeText'),
));




/*  Add link to file of featured image (the closing </a> tag is in the template file)
-----------------------------------------------------------------------------------*/
function full_size_link(){
	$image_id = get_post_thumbnail_id();
	$image_url = wp_get_attachment_image_src($image_id, 'fullsize', true);
	echo '<a href="'.$image_url[0].'" class="fullsize">';
}

/*  Custom excerpt
-----------------------------------------------------------------------------------*/
function cl_excerptlength_folio($length) {
    return 17;
}
function cl_excerptlength_widget($length) {
    return 18;
}
function cl_excerptlength_post($length) {
    return 70;
}
function cl_excerptmore($more) {
    return ' ...';
}
	
function cl_excerpt($length_callback='', $more_callback='') {

    global $post;
	
    if(function_exists($length_callback)){
		add_filter('excerpt_length', $length_callback);
    }
	
    if(function_exists($more_callback)){
		add_filter('excerpt_more', $more_callback);
    }
	
    $output = get_the_excerpt();
    $output = apply_filters('wptexturize', $output);
    $output = apply_filters('convert_chars', $output);
    $output = $output;
	
    echo $output;
	
}   

/*---------------------------------
	Function that replaces the default get_the_excerpt() function(only for shortcodes)
------------------------------------*/

function cl_get_excerpt($excerpt, $charlength) {

	$charlength++;
	$content = '';

	if ( mb_strlen( $excerpt ) > $charlength ) {
		$subex = mb_substr( $excerpt, 0, $charlength - 5 );
		$exwords = explode( ' ', $subex );
		$excut = - ( mb_strlen( $exwords[ count( $exwords ) - 1 ] ) );
		if ( $excut < 0 ) {
			$content .= mb_substr( $subex, 0, $excut );
		} else {
			$content .= $subex;
		}
		$content .= ' ...';
	} else {
		$content .= $excerpt;
	}

	return $content;
	
}

/*---------------------------------
	Function that refilters the get_the_excerpt() function
------------------------------------*/

function cl_refilter_excerpt( $output ) {
	if ( has_excerpt() && ! is_attachment() ) {
		$output = preg_replace('/<a[^>]+>Continue reading.*?<\/a>/i','',$output);
	}
	return $output;
}
add_filter( 'get_the_excerpt', 'cl_refilter_excerpt' );

/*---------------------------------
	Enable excerpts for pages
------------------------------------*/

add_post_type_support( 'page', 'excerpt' );

/*	Enable blog navigation
/*-----------------------------------------------------------------------------------*/
function show_posts_nav() {
   global $wp_query;
   return ($wp_query->max_num_pages > 1);
}



/*	Theme localization
/*-----------------------------------------------------------------------------------*/
load_theme_textdomain( 'themeText', get_template_directory().'/languages' );

$locale = get_locale();
$locale_file = get_template_directory()."/languages/$locale.php";
if ( is_readable($locale_file) )
	require_once($locale_file);
	
if ( function_exists('register_sidebar') )
	{
		register_sidebar(array( 'name' => __( 'Blog Search Sidebar', 'themeText' ),
								'id' => 'blog_search_sidebar',
								'before_widget' => '',
								'after_widget' => '',
								'before_title' => '<span style="display: none;">',
								'after_title' => '</span>'));
								
		register_sidebar(array( 'name' => __( 'Blog Sidebar 1', 'themeText' ),
								'id' => 'blog_sidebar_1',
								'before_widget' => '<section class="widget">',
								'after_widget' => '</section>',
								'before_title' => '<h3>',
								'after_title' => '</h3><hr>'));
								
		register_sidebar(array( 'name' => __( 'Blog Sidebar 2', 'themeText' ),
								'id' => 'blog_sidebar_2',
								'before_widget' => '<section class="widget">',
								'after_widget' => '</section>',
								'before_title' => '<h3>',
								'after_title' => '</h3><hr>'));
								
		register_sidebar(array( 'name' => __( 'Blog Sidebar 3', 'themeText' ),
								'id' => 'blog_sidebar_3',
								'before_widget' => '<section class="widget">',
								'after_widget' => '</section>',
								'before_title' => '<h3>',
								'after_title' => '</h3><hr>'));
								
		register_sidebar(array( 'name' => __( 'Blog Sidebar 4', 'themeText' ),
								'id' => 'blog_sidebar_4',
								'before_widget' => '<section class="widget">',
								'after_widget' => '</section>',
								'before_title' => '<h3>',
								'after_title' => '</h3><hr>'));
								
		register_sidebar(array( 'name' => __( 'Blog Sidebar 5', 'themeText' ),
								'id' => 'blog_sidebar_5',
								'before_widget' => '<section class="widget">',
								'after_widget' => '</section>',
								'before_title' => '<h3>',
								'after_title' => '</h3><hr>'));

		register_sidebar(array( 'name' => __( 'Blog Sidebar 6', 'themeText' ),
								'id' => 'blog_sidebar_6',
								'before_widget' => '<section class="widget">',
								'after_widget' => '</section>',
								'before_title' => '<h3>',
								'after_title' => '</h3><hr>'));
								
		register_sidebar(array( 'name' => __( 'Blog Sidebar 7', 'themeText' ),
								'id' => 'blog_sidebar_7',
								'before_widget' => '<section class="widget">',
								'after_widget' => '</section>',
								'before_title' => '<h3>',
								'after_title' => '</h3><hr>'));
								
		register_sidebar(array( 'name' => __( 'Footer Sidebar 1', 'themeText' ),
								'id' => 'footer_sidebar_1',
								'before_widget' => '',
								'after_widget' => '',
								'before_title' => '<h4 class="widgettitle">',
								'after_title' => '</h4><hr>'));
								
		register_sidebar(array( 'name' => __( 'Footer Sidebar 2', 'themeText' ),
								'id' => 'footer_sidebar_2',

								'before_widget' => '',
								'after_widget' => '',
								'before_title' => '<h4 class="widgettitle">',
								'after_title' => '</h4><hr>'));
								
		register_sidebar(array( 'name' => __( 'Footer Sidebar 3', 'themeText' ),
								'id' => 'footer_sidebar_3',
								'before_widget' => '',
								'after_widget' => '',
								'before_title' => '<h4 class="widgettitle">',
								'after_title' => '</h4><hr>'));
								
		register_sidebar(array( 'name' => __( 'Footer Sidebar 4', 'themeText' ),
								'id' => 'footer_sidebar_4',
								'before_widget' => '',
								'after_widget' => '',
								'before_title' => '<h4 class="widgettitle">',
								'after_title' => '</h4><hr>'));
								
	/* ------------------------------------------------------------------------------------------------------------------------------------------------------ */

	function post_image_size_info() { echo '<div class="admin-inside-box"><p>Recommended image size min 700px width.</p></div>'; }
	function portfolio_image_size_info() { echo '<div class="admin-inside-box"><p>Recommended image size min 700px width.</p></div>'; }
	
	function add_image_size_info()
	{
		add_meta_box( 'post_image_size_info', __( 'Featured Image Size', 'themeText' ), 'post_image_size_info', 'post', 'side', 'low' );
		add_meta_box( 'portfolio_image_size_info', __( 'Featured Image Size', 'themeText' ), 'portfolio_image_size_info', 'portfolio', 'side', 'low' );
	}
	
	add_action( 'admin_init', 'add_image_size_info' );
								
								
	}

/*-----------------------------------------------------------------------------------*/
/*	Post Formats
/*-----------------------------------------------------------------------------------*/

$formats = array( 
			'aside',
			'audio',
			'gallery', 
			'image', 
			'link', 
			'quote', 
			'video');

add_theme_support( 'post-formats', $formats ); 










?>